@@ -26,10 +26,7 @@ from util import delete_tempfile
 class QemuEfiMachine(enum.Enum):
     OVMF_PC = enum.auto()
     OVMF_Q35 = enum.auto()
-    OVMF32_PC = enum.auto()
-    OVMF32_Q35 = enum.auto()
     AAVMF = enum.auto()
-    AAVMF32 = enum.auto()
     RISCV64 = enum.auto()
     LOONGARCH64 = enum.auto()
 
@@ -71,9 +68,6 @@ class QemuCommand:
         QemuEfiMachine.AAVMF: [
             'qemu-system-aarch64', '-cpu', 'cortex-a57',
         ] + Aavmf_Common_Params,
-        QemuEfiMachine.AAVMF32: [
-            'qemu-system-arm', '-cpu', 'cortex-a15',
-        ] + Aavmf_Common_Params,
         QemuEfiMachine.LOONGARCH64: [
             'qemu-system-loongarch64',
         ] + LoongArch_Common_Params,
@@ -83,12 +77,6 @@ class QemuCommand:
         QemuEfiMachine.OVMF_Q35: [
             'qemu-system-x86_64', '-machine', 'q35,accel=tcg',
         ] + Ovmf_Common_Params,
-        QemuEfiMachine.OVMF32_PC: [
-            'qemu-system-i386', '-machine', 'pc,accel=tcg',
-        ] + Ovmf_Common_Params,
-        QemuEfiMachine.OVMF32_Q35: [
-            'qemu-system-i386', '-machine', 'q35,accel=tcg',
-        ] + Ovmf_Common_Params,
         QemuEfiMachine.RISCV64: [
             'qemu-system-riscv64',
         ] + RiscV_Common_Params,
@@ -123,13 +111,6 @@ class QemuCommand:
                 root / f'usr/share/AAVMF/AAVMF_CODE{code_ext}.fd',
                 root / f'usr/share/AAVMF/AAVMF_VARS{vars_ext}.fd'
             )
-        if machine == QemuEfiMachine.AAVMF32:
-            assert(variant is None)
-            assert(flash_size == QemuEfiFlashSize.DEFAULT)
-            return (
-                root / 'usr/share/AAVMF/AAVMF32_CODE.fd',
-                root / 'usr/share/AAVMF/AAVMF32_VARS.fd'
-            )
         if machine == QemuEfiMachine.LOONGARCH64:
             assert(variant is None)
             assert(flash_size == QemuEfiFlashSize.DEFAULT)
@@ -151,17 +132,11 @@ class QemuCommand:
             ]
         )
         size_ext = '_4M'
-        if machine in [QemuEfiMachine.OVMF_PC, QemuEfiMachine.OVMF32_PC]:
+        if machine in [QemuEfiMachine.OVMF_PC]:
             assert(variant is None)
-        if machine == QemuEfiMachine.OVMF32_Q35:
-            assert(variant is None or variant in [QemuEfiVariant.SECBOOT, QemuEfiVariant.SECBOOT_STRICTNX])
-        if machine in [QemuEfiMachine.OVMF32_PC, QemuEfiMachine.OVMF32_Q35]:
-            OVMF_ARCH = "OVMF32"
-        else:
-            OVMF_ARCH = "OVMF"
         return (
-            root / f'usr/share/OVMF/{OVMF_ARCH}_CODE{size_ext}{code_ext}.fd',
-            root / f'usr/share/OVMF/{OVMF_ARCH}_VARS{size_ext}{vars_ext}.fd',
+            root / f'usr/share/OVMF/OVMF_CODE{size_ext}{code_ext}.fd',
+            root / f'usr/share/OVMF/OVMF_VARS{size_ext}{vars_ext}.fd',
         )
 
     def __init__(
