@@ -302,11 +302,6 @@ class BootToShellTest(unittest.TestCase):
         q.add_disk(iso.path)
         self.run_cmd_check_secure_boot(q.command, 'aa64', False)
 
-    def test_aavmf32(self):
-        q = Qemu.QemuCommand(QemuEfiMachine.AAVMF32)
-        init_shell_entry(q.pflash.varfile.name, 'ArmVirt')
-        self.run_cmd_check_shell(q.command)
-
     @unittest.skipUnless(
         DpkgArch['DEB_BUILD_ARCH_BITS'] == '64', "Requires 64-bit QEMU",
     )
@@ -480,22 +475,6 @@ class BootToShellTest(unittest.TestCase):
         q.add_disk(iso.path)
         self.run_cmd_check_secure_boot(q.command, 'x64', False)
 
-    def test_ovmf32_4m_pc(self):
-        q = Qemu.QemuCommand(
-            QemuEfiMachine.OVMF32_PC,
-            flash_size=QemuEfiFlashSize.SIZE_4MB,
-        )
-        init_shell_entry(q.pflash.varfile.name, 'Ovmf')
-        self.run_cmd_check_shell(q.command)
-
-    def test_ovmf32_4m_q35(self):
-        q = Qemu.QemuCommand(
-            QemuEfiMachine.OVMF32_Q35,
-            flash_size=QemuEfiFlashSize.SIZE_4MB,
-        )
-        init_shell_entry(q.pflash.varfile.name, 'Ovmf')
-        self.run_cmd_check_shell(q.command)
-
     @unittest.skipUnless(
         DpkgArch['DEB_BUILD_ARCH_BITS'] == '64', "Requires 64-bit QEMU",
     )
